/**
 * @packageDocumentation
 * @module Components
 */
import React from 'react';
import { StyleProp, ViewStyle } from 'react-native';
/**
 * @param title  The text to use inside of the button.
 * @param onPress  The function to handle the on press action.
 * @param style  (Optional) Custom style to style the button.
 * @param fontSize  (Optional) The font size of the text in the button. Default 16.
 * @param numberOfLines  (Optional) The number of lines of text in the button. Default 1.
 * @param theme (Optional) react-native-paper theme partial to style the component.
 *
 */
export declare type ResizingClearButtonProps = {
    title: string;
    onPress: () => void;
    style?: StyleProp<ViewStyle>;
    fontSize?: number;
    numberOfLines?: number;
    theme?: ReactNativePaper.Theme;
};
/**
 * Creates a transparent text button which handles text scaling (e.g. for long textual content).
 * The passed font size will be the size when the button is not width-constrained. Otherwise, the
 * text will shrink to fit the available space.
 *
 * @category Component
 */
export declare const ResizingClearButton: React.FC<ResizingClearButtonProps>;
