/**
 * @packageDocumentation
 * @module Components
 */
import React from 'react';
import { StyleProp, ViewStyle } from 'react-native';
/**
 * @param text  The text shown inside of the button
 * @param style  (Optional) Custom style to style the button.
 * @param outlined  (Optional) If true, the button will not have a background color, but an outline.
 * @param disabled  (Optional) If true, the button will be disabled.
 * @param onPress  Action to take when button is tapped.
 * @param theme (Optional) react-native-paper theme partial to style the component.
 */
export declare type ToggleButtonProps = {
    text: string;
    style?: StyleProp<ViewStyle>;
    outlined?: boolean;
    disabled?: boolean;
    onPress: () => void;
    theme?: ReactNativePaper.Theme;
};
/**
 * Displays a Brightlayer UI compliant button which may be disabled. Optionally present as an outline-only button.
 *
 * @category Component
 */
export declare const ToggleButton: React.FC<ToggleButtonProps>;
